<?php

declare(strict_types = 1);

namespace Drupal\Tests\cmis\Functional;

use Drupal\cmis\CmisConnectionApi;
use Drupal\cmis\Entity\CmisConnectionEntity;

/**
 * Tests login Alfresco.
 *
 * @group cmis
 */
class LoginAlfrescoTest extends CmisFunctionalTestBase {

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $cmis_connection = CmisConnectionEntity::create([
      'label' => 'alfresco',
      'id' => 'alfresco',
      'cmis_url' => $_ENV['CMIS_URL_ALFRESCO'] ?? 'http://proxy:8080/alfresco/api/-default-/public/cmis/versions/1.1/browser',
      'cmis_user' => $_ENV['CMIS_USER_ALFRESCO'] ?? 'admin',
      'cmis_password' => $_ENV['CMIS_PASSWORD_ALFRESCO'] ?? 'admin',
    ]);
    $cmis_connection->save();
  }

  /**
   * Test Cmis query in Alfresco.
   */
  public function testCmisQueryAlfresco(): void {
    $connection_alfresco = new CmisConnectionApi('alfresco');
    if (!empty($connection_alfresco->getHttpInvoker())) {
      $connection_alfresco->setDefaultParameters();
      $session = $connection_alfresco->getSession();
      $results = $session->query("SELECT * FROM cmis:folder WHERE cmis:name='Company Home'");
      $description = $results[0]->getPropertyValueById('cmis:description');
      $this->assertEquals('The company root space', $description);
    }
  }

}
